<sly-select-app-session
    :group-id="data.{{{widget.widget_id}}}.teamId"
    :app-session-id.sync="state.{{{widget.widget_id}}}.sessionId"
    :options="data.{{{widget.widget_id}}}.ssOptions"
    :disabled="data.{{{widget.widget_id}}}.disabled">
</sly-select-app-session>